searchNodes=[{"doc":"Tempus is a library to deal with timeslots. It aims to be a fast yet easy to use implementation of a schedule of any type, including but not limited to free/busy time schedules. The example of it might be a calendar software, where slots might be marked as free, or busy. It also allows simple arithmetics with schedules, like adding five days or subtracting 7 hours 30 minutes from now, considering busy slots.","ref":"Tempus.html","title":"Tempus","type":"module"},{"doc":"Adds an amount of units to the origin, considering slots given.","ref":"Tempus.html#add/4","title":"Tempus.add/4","type":"function"},{"doc":"Returns the reversed list of free days after origin. Examples iex&gt; slots = [ ...&gt; Tempus.Slot . wrap ( ~D|2020-08-07| ) , ...&gt; Tempus.Slot . wrap ( ~D|2020-08-10| ) ...&gt; ] |&gt; Enum . into ( % Tempus.Slots { } ) iex&gt; Tempus . days_add ( slots , origin : ~D|2020-08-07| , count : 3 ) |&gt; hd ( ) ~D|2020-08-12| iex&gt; Tempus . days_add ( slots , origin : ~D|2020-08-07| , count : 3 , direction : :fwd ) |&gt; hd ( ) ~D|2020-08-12| iex&gt; Tempus . days_add ( slots , origin : ~D|2020-08-07| , count : - 3 , direction : :bwd ) |&gt; hd ( ) ~D|2020-08-12| iex&gt; Tempus . days_add ( slots , origin : ~D|2020-08-12| , count : - 4 ) |&gt; hd ( ) ~D|2020-08-06| iex&gt; Tempus . days_add ( slots , origin : ~D|2020-08-12| , count : 4 , direction : :bwd ) |&gt; hd ( ) ~D|2020-08-06| iex&gt; Tempus . days_add ( slots , origin : ~D|2020-08-12| , count : - 4 , direction : :fwd ) |&gt; hd ( ) ~D|2020-08-06|","ref":"Tempus.html#days_add/2","title":"Tempus.days_add/2","type":"function"},{"doc":"Returns the reversed list of free days after origin. Examples iex&gt; slots = [ ...&gt; Tempus.Slot . wrap ( ~D|2020-08-07| ) , ...&gt; Tempus.Slot . wrap ( ~D|2020-08-10| ) ...&gt; ] |&gt; Enum . into ( % Tempus.Slots { } ) iex&gt; Tempus . days_ago ( slots , ~D|2020-08-07| , 0 ) [ ~D|2020-08-06| ] iex&gt; Tempus . days_ago ( slots , ~D|2020-08-12| , 4 ) |&gt; hd ( ) ~D|2020-08-06|","ref":"Tempus.html#days_ago/3","title":"Tempus.days_ago/3","type":"function"},{"doc":"Returns the reversed list of free days after origin. Examples iex&gt; slots = [ ...&gt; Tempus.Slot . wrap ( ~D|2020-08-07| ) , ...&gt; Tempus.Slot . wrap ( ~D|2020-08-10| ) ...&gt; ] |&gt; Enum . into ( % Tempus.Slots { } ) iex&gt; Tempus . days_ahead ( slots , ~D|2020-08-07| , 0 ) [ ~D|2020-08-08| ] iex&gt; Tempus . days_ahead ( slots , ~D|2020-08-07| , 3 ) |&gt; hd ( ) ~D|2020-08-12|","ref":"Tempus.html#days_ahead/3","title":"Tempus.days_ahead/3","type":"function"},{"doc":"Drops slots at the beginning of the %Slots{} struct while fun returns a truthy value.","ref":"Tempus.html#drop_while/2","title":"Tempus.drop_while/2","type":"function"},{"doc":"Checks whether the slot is disjoined against slots. Examples iex&gt; slots = [ ...&gt; Tempus.Slot . wrap ( ~D|2020-08-07| ) , ...&gt; Tempus.Slot . wrap ( ~D|2020-08-10| ) ...&gt; ] |&gt; Enum . into ( % Tempus.Slots { } ) iex&gt; Tempus . free? ( slots , ~D|2020-08-07| ) false iex&gt; Tempus . free? ( slots , ~D|2020-08-08| ) true","ref":"Tempus.html#free?/3","title":"Tempus.free?/3","type":"function"},{"doc":"Helper to instantiate slot from any known format, by wrapping the argument. Examples iex&gt; Tempus . guess ( &quot;2023-04-10&quot; ) { :ok , Tempus.Slot . wrap ( ~D[2023-04-10] ) } iex&gt; Tempus . guess ( &quot;2023-04-10T10:00:00Z&quot; ) { :ok , Tempus.Slot . wrap ( ~U[2023-04-10T10:00:00Z] ) } iex&gt; Tempus . guess ( &quot;20230410T235007.123+0230&quot; ) if Version . compare ( System . version ( ) , &quot;1.14.0&quot; ) == :lt do { :error , :invalid_format } else { :ok , Tempus.Slot . wrap ( ~U[2023-04-10T21:20:07.123Z] ) } end iex&gt; Tempus . guess ( &quot;2023-04-10-15&quot; ) { :error , :invalid_format }","ref":"Tempus.html#guess/1","title":"Tempus.guess/1","type":"function"},{"doc":"Helper to instantiate slot from any known format, by joining the arguments. Examples iex&gt; import Tempus.Sigils iex&gt; Tempus . guess ( &quot;2023-04-10&quot; , &quot;2023-04-12&quot; ) { :ok , ~I[2023-04-10 00:00:00.000000Z|2023-04-12 23:59:59.999999Z] } iex&gt; Tempus . guess ( &quot;2023-04-10T10:00:00Z&quot; , &quot;2023-04-12&quot; ) { :ok , ~I[2023-04-10 10:00:00Z|2023-04-12 23:59:59.999999Z] } iex&gt; Tempus . guess ( &quot;20230410T235007.123+0230&quot; , &quot;2023-04-12&quot; ) if Version . compare ( System . version ( ) , &quot;1.14.0&quot; ) == :lt do { :error , { :invalid_arguments , [ from : :invalid_format ] } } else { :ok , ~I[2023-04-10 21:20:07.123Z|2023-04-12 23:59:59.999999Z] } end iex&gt; Tempus . guess ( &quot;2023-04-10-15&quot; , :ok ) { :error , { :invalid_arguments , [ from : :invalid_format , to : :invalid_argument ] } }","ref":"Tempus.html#guess/2","title":"Tempus.guess/2","type":"function"},{"doc":"Returns the next busy slot from the slots passed as a first argument, that immediately follows origin . IOf slots are overlapped, the overlapped one gets returned. Examples iex&gt; slots = [ ...&gt; Tempus.Slot . wrap ( ~D|2020-08-07| ) , ...&gt; Tempus.Slot . wrap ( ~D|2020-08-10| ) ...&gt; ] |&gt; Enum . into ( % Tempus.Slots { } ) iex&gt; Tempus . next_busy ( slots , origin : % Tempus.Slot { from : ~U|2020-08-08 23:00:00Z| , to : ~U|2020-08-09 12:00:00Z| } ) # Slot &lt; [ from : ~U[2020-08-10 00:00:00.000000Z] , to : ~U[2020-08-10 23:59:59.999999Z] ] &gt; iex&gt; Tempus . next_busy ( slots , origin : % Tempus.Slot { from : ~U|2020-08-07 11:00:00Z| , to : ~U|2020-08-07 12:00:00Z| } , count : 2 ) |&gt; hd ( ) # Slot &lt; [ from : ~U[2020-08-07 00:00:00.000000Z] , to : ~U[2020-08-07 23:59:59.999999Z] ] &gt; iex&gt; Tempus . next_busy ( slots , origin : % Tempus.Slot { from : ~U|2020-08-07 11:00:00Z| , to : ~U|2020-08-08 12:00:00Z| } ) # Slot &lt; [ from : ~U[2020-08-07 00:00:00.000000Z] , to : ~U[2020-08-07 23:59:59.999999Z] ] &gt; iex&gt; Tempus . next_busy ( slots , origin : % Tempus.Slot { from : ~U|2020-08-07 11:00:00Z| , to : ~U|2020-08-10 12:00:00Z| } ) # Slot &lt; [ from : ~U[2020-08-07 00:00:00.000000Z] , to : ~U[2020-08-07 23:59:59.999999Z] ] &gt; iex&gt; Tempus . next_busy ( slots , origin : ~D|2020-08-07| ) # Slot &lt; [ from : ~U[2020-08-07 00:00:00.000000Z] , to : ~U[2020-08-07 23:59:59.999999Z] ] &gt; iex&gt; Tempus . next_busy ( slots , origin : ~D|2020-08-08| ) # Slot &lt; [ from : ~U[2020-08-10 00:00:00.000000Z] , to : ~U[2020-08-10 23:59:59.999999Z] ] &gt; iex&gt; Tempus . next_busy ( slots , origin : ~D|2020-08-08| , direction : :bwd ) # Slot &lt; [ from : ~U[2020-08-07 00:00:00.000000Z] , to : ~U[2020-08-07 23:59:59.999999Z] ] &gt; iex&gt; Tempus . next_busy ( slots , origin : ~D|2020-08-10| , direction : :bwd ) # Slot &lt; [ from : ~U[2020-08-10 00:00:00.000000Z] , to : ~U[2020-08-10 23:59:59.999999Z] ] &gt; iex&gt; Tempus . next_busy ( slots , origin : % Tempus.Slot { from : ~U|2020-08-11 11:00:00Z| , to : ~U|2020-08-11 12:00:00Z| } ) nil iex&gt; Tempus . next_busy ( slots , origin : % Tempus.Slot { from : ~U|2020-08-06 11:00:00Z| , to : ~U|2020-08-06 12:00:00Z| } , direction : :bwd ) nil iex&gt; Tempus . next_busy ( % Tempus.Slots { } ) nil","ref":"Tempus.html#next_busy/2","title":"Tempus.next_busy/2","type":"function"},{"doc":"Returns the next free slot from the slots passed as a first argument, that immediately follows origin . If slots are overlapped, the overlapped one gets returned. Examples iex&gt; slots = [ ...&gt; Tempus.Slot . wrap ( ~D|2020-08-07| ) , ...&gt; Tempus.Slot . wrap ( ~D|2020-08-10| ) , ...&gt; Tempus.Slot . wrap ( ~D|2020-08-12| ) , ...&gt; Tempus.Slot . wrap ( ~D|2020-08-14| ) ...&gt; ] |&gt; Enum . into ( % Tempus.Slots { } ) iex&gt; Tempus . next_free ( slots , origin : % Tempus.Slot { from : ~U|2020-08-08 23:00:00Z| , to : ~U|2020-08-09 12:00:00Z| } ) # Slot &lt; [ from : ~U[2020-08-08 00:00:00.000000Z] , to : ~U[2020-08-09 23:59:59.999999Z] ] &gt; iex&gt; Tempus . next_free ( slots , origin : % Tempus.Slot { from : ~U|2020-08-06 11:00:00Z| , to : ~U|2020-08-06 12:00:00Z| } ) # Slot &lt; [ from : ~U[2020-08-06 11:00:00.000000Z] , to : ~U[2020-08-06 23:59:59.999999Z] ] &gt; iex&gt; Tempus . next_free ( slots , origin : ~U|2020-08-13 01:00:00.000000Z| ) # Slot &lt; [ from : ~U[2020-08-13 00:00:00.000000Z] , to : ~U[2020-08-13 23:59:59.999999Z] ] &gt; iex&gt; Tempus . next_free ( slots , origin : ~D|2020-08-13| ) # Slot &lt; [ from : ~U[2020-08-13 00:00:00.000000Z] , to : ~U[2020-08-13 23:59:59.999999Z] ] &gt; iex&gt; Tempus . next_free ( slots , origin : ~D|2020-08-14| ) # Slot &lt; [ from : ~U[2020-08-15 00:00:00.000000Z] , to : nil ] &gt; iex&gt; Tempus . next_free ( slots , origin : ~D|2020-08-07| , count : 5 ) [ % Tempus.Slot { from : ~U[2020-08-08 00:00:00.000000Z] , to : ~U[2020-08-09 23:59:59.999999Z] } , % Tempus.Slot { from : ~U[2020-08-11 00:00:00.000000Z] , to : ~U[2020-08-11 23:59:59.999999Z] } , % Tempus.Slot { from : ~U[2020-08-13 00:00:00.000000Z] , to : ~U[2020-08-13 23:59:59.999999Z] } , % Tempus.Slot { from : ~U[2020-08-15 00:00:00.000000Z] , to : nil } ] iex&gt; Tempus . next_free ( slots , origin : ~D|2020-08-15| , count : - 5 ) [ % Tempus.Slot { from : ~U[2020-08-15 00:00:00.000000Z] , to : ~U[2020-08-15 23:59:59.999999Z] } , % Tempus.Slot { from : ~U[2020-08-13 00:00:00.000000Z] , to : ~U[2020-08-13 23:59:59.999999Z] } , % Tempus.Slot { from : ~U[2020-08-11 00:00:00.000000Z] , to : ~U[2020-08-11 23:59:59.999999Z] } , % Tempus.Slot { from : ~U[2020-08-08 00:00:00.000000Z] , to : ~U[2020-08-09 23:59:59.999999Z] } , % Tempus.Slot { from : nil , to : ~U[2020-08-06 23:59:59.999999Z] } , ] iex&gt; Tempus . next_free ( slots , origin : ~D|2020-08-12| , count : :infinity , direction : :bwd ) [ % Tempus.Slot { from : ~U[2020-08-11 00:00:00.000000Z] , to : ~U[2020-08-11 23:59:59.999999Z] } , % Tempus.Slot { from : ~U[2020-08-08 00:00:00.000000Z] , to : ~U[2020-08-09 23:59:59.999999Z] } , % Tempus.Slot { from : nil , to : ~U[2020-08-06 23:59:59.999999Z] } ]","ref":"Tempus.html#next_free/2","title":"Tempus.next_free/2","type":"function"},{"doc":"Slices the %Slots{} based on origins from and to and an optional type (default: :reluctant .) Returns sliced %Slots{} back.","ref":"Tempus.html#slice/4","title":"Tempus.slice/4","type":"function"},{"doc":"See Tempus.Slot.new/2 .","ref":"Tempus.html#slot/2","title":"Tempus.slot/2","type":"function"},{"doc":"See Tempus.Slot.new!/2 .","ref":"Tempus.html#slot!/2","title":"Tempus.slot!/2","type":"function"},{"doc":"Syntactic sugar for |&gt; Enum.into(%Slots{}) . Examples iex&gt; [ ...&gt; Tempus.Slot . wrap ( ~D|2020-08-07| ) , ...&gt; Tempus.Slot . wrap ( ~D|2020-08-10| ) , ...&gt; Tempus.Slot . wrap ( ~D|2020-08-12| ) ...&gt; ] |&gt; Tempus . slots ( ) % Tempus.Slots { slots : [ % Tempus.Slot { from : ~U[2020-08-07 00:00:00.000000Z] , to : ~U[2020-08-07 23:59:59.999999Z] } , % Tempus.Slot { from : ~U[2020-08-10 00:00:00.000000Z] , to : ~U[2020-08-10 23:59:59.999999Z] } , % Tempus.Slot { from : ~U[2020-08-12 00:00:00.000000Z] , to : ~U[2020-08-12 23:59:59.999999Z] } ] }","ref":"Tempus.html#slots/1","title":"Tempus.slots/1","type":"function"},{"doc":"Takes slots at the beginning of the %Slots{} struct while fun returns a truthy value.","ref":"Tempus.html#take_while/2","title":"Tempus.take_while/2","type":"function"},{"doc":"Number of slots ( :stream means lazy folding, unknown upfront)","ref":"Tempus.html#t:count/0","title":"Tempus.count/0","type":"type"},{"doc":"Direction for slots navigation","ref":"Tempus.html#t:direction/0","title":"Tempus.direction/0","type":"type"},{"doc":"Navigation option","ref":"Tempus.html#t:option/0","title":"Tempus.option/0","type":"type"},{"doc":"Argument containing navigation options","ref":"Tempus.html#t:options/0","title":"Tempus.options/0","type":"type"},{"doc":"The type defining how slicing is to be applied. When :greedy , overlapping boundary slots would be included, :reluctant would take only those fully contained in the interval.","ref":"Tempus.html#t:slice_type/0","title":"Tempus.slice_type/0","type":"type"},{"doc":"Handy guards to simplify pattern matching slots","ref":"Tempus.Guards.html","title":"Tempus.Guards","type":"module"},{"doc":"Guard to compare two instances of Tempus.Slot.origin/0 Examples iex&gt; import Tempus.Guards , only : [ is_coming_before : 2 ] ...&gt; is_coming_before ( ~D[2023-04-10] , ~U[2023-04-11T00:00:00.000000Z] ) true ...&gt; is_coming_before ( ~D[2023-04-10] , ~D[2023-04-10] ) false","ref":"Tempus.Guards.html#is_coming_before/2","title":"Tempus.Guards.is_coming_before/2","type":"macro"},{"doc":"Guard to validate the slot covers the origin passed as the first argument Examples iex&gt; import Tempus.Guards , only : [ is_covered : 2 ] ...&gt; import Tempus.Sigils ...&gt; { from , to } = { ~U[2023-04-10 00:00:00Z] , ~U[2023-04-10 00:59:59Z] } ...&gt; s = % Tempus.Slot { from : from , to : to } ...&gt; is_covered ( from , s ) and is_covered ( to , s ) true ...&gt; s1 = ~I[2023-04-10 00:00:00Z|2023-04-11 00:00:00Z] ...&gt; s2 = Tempus.Slot . wrap ( ~D|2023-04-10| ) ...&gt; is_covered ( s1 , s2 ) false ...&gt; s1 = ~I[2023-04-10 00:00:00Z|2023-04-11 00:00:00Z] ...&gt; s2 = Tempus.Slot . wrap ( ~D|2023-04-10| ) ...&gt; is_covered ( s1 , s2 ) false","ref":"Tempus.Guards.html#is_covered/2","title":"Tempus.Guards.is_covered/2","type":"macro"},{"doc":"Guard to validate one slot ovelaps another Examples iex&gt; import Tempus.Guards , only : [ is_joint : 2 ] ...&gt; import Tempus.Sigils ...&gt; s1 = ~I[2023-04-09 23:00:00Z|2023-04-10 00:59:59Z] ...&gt; s2 = Tempus.Slot . wrap ( ~D|2023-04-10| ) ...&gt; is_joint ( s1 , s2 ) true ...&gt; s1 = ~I[2023-04-09 23:00:00Z|2023-04-10 00:00:00Z] ...&gt; s2 = Tempus.Slot . wrap ( ~D|2023-04-10| ) ...&gt; is_joint ( s1 , s2 ) true","ref":"Tempus.Guards.html#is_joint/2","title":"Tempus.Guards.is_joint/2","type":"macro"},{"doc":"Guard to validate that the term given is actually a Tempus.Slot.origin/0 Examples iex&gt; import Tempus.Guards , only : [ is_origin : 1 ] ...&gt; is_origin ( Date . utc_today ( ) ) true ...&gt; is_origin ( nil ) true ...&gt; is_origin ( :ok ) false","ref":"Tempus.Guards.html#is_origin/1","title":"Tempus.Guards.is_origin/1","type":"macro"},{"doc":"Guard to validate whether the DateTime.t/0 given as the first argument is the border of the slot.","ref":"Tempus.Guards.html#is_slot_border/2","title":"Tempus.Guards.is_slot_border/2","type":"macro"},{"doc":"Guard to validate whether two slots are equal Examples iex&gt; import Tempus.Guards , only : [ is_slot_equal : 2 ] ...&gt; import Tempus.Sigils ...&gt; s1 = ~I[2023-04-09 00:00:00Z|2023-04-09 23:59:59.999999Z] ...&gt; s2 = Tempus.Slot . wrap ( ~D|2023-04-09| ) ...&gt; s3 = ~I[2023-04-09 00:00:00Z|2023-04-09 23:59:59Z] ...&gt; is_slot_equal ( s1 , s1 ) true ...&gt; is_slot_equal ( s1 , s2 ) true ...&gt; is_slot_equal ( s1 , s3 ) false","ref":"Tempus.Guards.html#is_slot_equal/2","title":"Tempus.Guards.is_slot_equal/2","type":"macro"},{"doc":"Guard to validate whether the slot is nil (has neither end set.)","ref":"Tempus.Guards.html#is_slot_nil/1","title":"Tempus.Guards.is_slot_nil/1","type":"macro"},{"doc":"Guard to validate whether the slot is open (has either end not set) Please note, that the slot having both ends set to nil is considered a special case and is not reported as open .","ref":"Tempus.Guards.html#is_slot_open/1","title":"Tempus.Guards.is_slot_open/1","type":"macro"},{"doc":"Helper to validate one slot overlaps another in delta. Unlike guards, this function does not expect arguments in the correct order, and would return true if the slots overlap even if s2 comes before s1 . Examples iex&gt; import Tempus.Guards , only : [ joint_in_delta? : 3 ] ...&gt; import Tempus.Sigils ...&gt; s1 = ~I[2023-04-09 23:00:00Z|2023-04-09 23:59:59Z] ...&gt; s2 = Tempus.Slot . wrap ( ~D|2023-04-10| ) ...&gt; joint_in_delta? ( s1 , s2 , 1 ) true ...&gt; joint_in_delta? ( s2 , s1 , 1 ) true ...&gt; joint_in_delta? ( s1 , s2 , { 0 , 500 } ) false","ref":"Tempus.Guards.html#joint_in_delta?/3","title":"Tempus.Guards.joint_in_delta?/3","type":"function"},{"doc":"Handy sigils to instantiate Tempus.Slot and Tempus.Slots","ref":"Tempus.Sigils.html","title":"Tempus.Sigils","type":"module"},{"doc":"Parses the sigil-like binary representation of a Tempus.Slot . Examples iex&gt; Tempus.Sigils . parse ( &quot;2021-03-30T06:35:40Z|2021-03-30T06:36:00Z&quot; ) { :ok , % Tempus.Slot { from : ~U[2021-03-30 06:35:40Z] , to : ~U[2021-03-30 06:36:00Z] } }","ref":"Tempus.Sigils.html#parse/1","title":"Tempus.Sigils.parse/1","type":"function"},{"doc":"Handles the sigil ~I for Tempus.Slot . It returns a slot without interpolations and without escape characters, except for the escaping of the closing sigil character itself. Allowed separators: | , → , -&gt; , .. (might be surrounded by spaces) Allowed modifiers: none — expects two instances of DateTime single letter , one of d , t , u — both values are expected to be of that type any combination of two letters d , t , u  — the values are treated respectively g — the value types are to be guessed Examples iex&gt; import Tempus.Sigils iex&gt; ~I(2021-03-30T06:35:40Z|2021-03-30T06:36:00Z) % Tempus.Slot { from : ~U[2021-03-30 06:35:40Z] , to : ~U[2021-03-30 06:36:00Z] } iex&gt; ~I(2021-03-30 → 2021-03-31)d % Tempus.Slot { from : ~U[2021-03-30 00:00:00.000000Z] , to : ~U[2021-03-31 23:59:59.999999Z] } iex&gt; ~I(2021-03-30)d % Tempus.Slot { from : ~U[2021-03-30 00:00:00.000000Z] , to : ~U[2021-03-30 23:59:59.999999Z] } iex&gt; ~I(2021-03-30 06:35:40Z .. 2021-03-30 06:36:00Z)g % Tempus.Slot { from : ~U[2021-03-30 06:35:40Z] , to : ~U[2021-03-30 06:36:00Z] }","ref":"Tempus.Sigils.html#sigil_I/2","title":"Tempus.Sigils.sigil_I/2","type":"macro"},{"doc":"Declares a timeslot and exports functions to check whether the given date and/or datetime is covered by this slot or not. This module probably should not be called directly.","ref":"Tempus.Slot.html","title":"Tempus.Slot","type":"module"},{"doc":"Compares two slot structs. Returns :gt if first slot is strictly later than the second and :lt for vice versa. NB :eq is returned not only if slots are equal, but also when they are overlapped. Might be used in Enum.sort/2 .","ref":"Tempus.Slot.html#compare/3","title":"Tempus.Slot.compare/3","type":"function"},{"doc":"Checks whether to Slot covers the data/datetime passed as a second argument. Examples iex&gt; dt_between = ~U|2015-09-30 01:00:00Z| ...&gt; dt_from = ~U|2015-09-30 00:00:00Z| ...&gt; dt_to = ~U|2015-10-01 01:00:00Z| ...&gt; d_from = Date . from_iso8601! ( &quot;2015-09-30&quot; ) ...&gt; d_to = Date . from_iso8601! ( &quot;2015-10-01&quot; ) iex&gt; slot = % Tempus.Slot { from : dt_from , to : dt_to } iex&gt; Tempus.Slot . cover? ( slot , dt_between ) true iex&gt; Tempus.Slot . cover? ( slot , dt_to ) true iex&gt; Tempus.Slot . cover? ( slot , dt_to , true ) false iex&gt; Tempus.Slot . cover? ( slot , d_from ) true iex&gt; Tempus.Slot . cover? ( slot , d_from , true ) false iex&gt; Tempus.Slot . cover? ( slot , d_to ) false","ref":"Tempus.Slot.html#cover?/3","title":"Tempus.Slot.cover?/3","type":"function"},{"doc":"Returns true if two slots are disjoined, false otherwise. Examples iex&gt; slot = % Tempus.Slot { from : ~U|2015-09-01 00:00:00Z| , to : ~U|2015-10-01 00:00:00Z| } iex&gt; inner = % Tempus.Slot { from : ~U|2015-09-01 00:00:00Z| , to : ~U|2015-09-01 01:00:00Z| } iex&gt; Tempus.Slot . disjoint? ( slot , inner ) false iex&gt; inner = % Tempus.Slot { from : ~U|2015-09-01 00:00:00Z| , to : ~U|2015-10-01 01:00:00Z| } iex&gt; Tempus.Slot . disjoint? ( slot , inner ) false iex&gt; outer = % Tempus.Slot { from : ~U|2015-10-01 00:00:01Z| , to : ~U|2015-10-01 01:00:00Z| } iex&gt; Tempus.Slot . disjoint? ( slot , outer ) true","ref":"Tempus.Slot.html#disjoint?/2","title":"Tempus.Slot.disjoint?/2","type":"function"},{"doc":"Calculates the duration of a slot in units given as a second parameter (default: :second .) Example iex&gt; ~D|2020-09-03| |&gt; Tempus.Slot . wrap ( ) |&gt; Tempus.Slot . duration ( ) 86400","ref":"Tempus.Slot.html#duration/2","title":"Tempus.Slot.duration/2","type":"function"},{"doc":"Intersects slots to the minimal covered timeslice. Example iex&gt; Tempus.Slot . intersect ( [ Tempus.Slot . wrap ( ~D|2020-09-30| ) , ...&gt; % Tempus.Slot { from : ~U|2020-09-30 23:00:00Z| , to : ~U|2020-10-02 00:00:00Z| } ] ) # Slot &lt; [ from : ~U[2020-09-30 23:00:00Z] , to : ~U[2020-09-30 23:59:59.999999Z] ] &gt;","ref":"Tempus.Slot.html#intersect/1","title":"Tempus.Slot.intersect/1","type":"function"},{"doc":"Joins slots to the maximal covered timeslice. Example iex&gt; Tempus.Slot . join ( [ Tempus.Slot . wrap ( ~D|2020-09-30| ) , Tempus.Slot . wrap ( ~D|2020-10-02| ) ] ) # Slot &lt; [ from : ~U[2020-09-30 00:00:00.000000Z] , to : ~U[2020-10-02 23:59:59.999999Z] ] &gt; iex&gt; Tempus.Slot . join ( [ ~D|2020-09-30| , ~D|2020-10-02| ] ) # Slot &lt; [ from : ~U[2020-09-30 00:00:00.000000Z] , to : ~U[2020-10-02 23:59:59.999999Z] ] &gt;","ref":"Tempus.Slot.html#join/1","title":"Tempus.Slot.join/1","type":"function"},{"doc":"Joins two slots to the maximal covered timeslice. Example iex&gt; Tempus.Slot . join ( Tempus.Slot . wrap ( ~D|2020-09-30| ) , Tempus.Slot . wrap ( ~D|2020-10-02| ) ) # Slot &lt; [ from : ~U[2020-09-30 00:00:00.000000Z] , to : ~U[2020-10-02 23:59:59.999999Z] ] &gt; iex&gt; Tempus.Slot . join ( ~D|2020-09-30| , ~D|2020-10-02| ) # Slot &lt; [ from : ~U[2020-09-30 00:00:00.000000Z] , to : ~U[2020-10-02 23:59:59.999999Z] ] &gt;","ref":"Tempus.Slot.html#join/2","title":"Tempus.Slot.join/2","type":"function"},{"doc":"Returns true if two slots are neighbours, false otherwise. Examples iex&gt; slot = % Tempus.Slot { from : ~U|2015-09-01 00:00:00Z| , to : ~U|2015-10-01 23:59:59Z| } iex&gt; Tempus.Slot . neighbour? ( slot , Tempus.Slot . wrap ( ~D|2015-10-02| ) ) true iex&gt; Tempus.Slot . neighbour? ( slot , Tempus.Slot . wrap ( ~D|2015-08-31| ) ) true iex&gt; Tempus.Slot . neighbour? ( slot , Tempus.Slot . wrap ( ~D|2015-10-01| ) ) false iex&gt; Tempus.Slot . neighbour? ( slot , Tempus.Slot . wrap ( ~D|2015-10-03| ) ) false","ref":"Tempus.Slot.html#neighbour?/2","title":"Tempus.Slot.neighbour?/2","type":"function"},{"doc":"Creates new slot using arg[:from] as a starting origin and arg[:to] and an ending origin. Examples iex&gt; Tempus.Slot . new ( from : ~U|2015-09-30 00:00:00Z| , to : ~U|2015-10-01 01:00:00Z| ) { :ok , % Tempus.Slot { from : ~U|2015-09-30 00:00:00Z| , to : ~U|2015-10-01 01:00:00Z| } } iex&gt; Tempus.Slot . new ( %{ from : ~D|2015-09-30| , to : ~U|2015-10-01T12:00:00Z| } ) { :ok , % Tempus.Slot { from : ~U|2015-09-30 00:00:00.000000Z| , to : ~U|2015-10-01 12:00:00Z| } }","ref":"Tempus.Slot.html#new/1","title":"Tempus.Slot.new/1","type":"function"},{"doc":"Creates new slot using from as a starting origin and to and an ending origin. See new/1 for more readable implementation. Examples iex&gt; Tempus.Slot . new ( ~U|2015-09-30 00:00:00Z| , ~U|2015-10-01 01:00:00Z| ) { :ok , % Tempus.Slot { from : ~U|2015-09-30 00:00:00Z| , to : ~U|2015-10-01 01:00:00Z| } } iex&gt; Tempus.Slot . new ( ~D|2015-09-30| , ~U|2015-10-01T12:00:00Z| ) { :ok , % Tempus.Slot { from : ~U|2015-09-30 00:00:00.000000Z| , to : ~U|2015-10-01 12:00:00Z| } } iex&gt; Tempus.Slot . new ( :ok , :ok ) { :error , :invalid_input }","ref":"Tempus.Slot.html#new/2","title":"Tempus.Slot.new/2","type":"function"},{"doc":"Creates new slot using from as a starting origin and to and an ending origin. Unlike new/1 , this function raises on malformed input. Examples iex&gt; Tempus.Slot . new! ( ~U|2015-09-30 00:00:00Z| , ~U|2015-10-01 01:00:00Z| ) % Tempus.Slot { from : ~U|2015-09-30 00:00:00Z| , to : ~U|2015-10-01 01:00:00Z| } iex&gt; Tempus.Slot . new! ( ~D|2015-09-30| , ~U|2015-10-01T12:00:00Z| ) % Tempus.Slot { from : ~U|2015-09-30 00:00:00.000000Z| , to : ~U|2015-10-01 12:00:00Z| } iex&gt; Tempus.Slot . new! ( :ok , :ok ) ** (ArgumentError) malformed from/to argument, expected `origin`","ref":"Tempus.Slot.html#new!/2","title":"Tempus.Slot.new!/2","type":"function"},{"doc":"Shifts both from and to values to UTC zone. Examples slot = % Tempus.Slot { from : DateTime . from_naive! ( ~N|2018-01-05 21:00:00| , &quot;America/New_York&quot; ) , to : DateTime . from_naive! ( ~N|2018-01-08 08:59:59| , &quot;Australia/Sydney&quot; ) } #⇒ #Slot&lt;[from: ~U[2018-01-06 02:00:00Z], to: ~U[2018-01-07 21:59:59Z]]&gt;","ref":"Tempus.Slot.html#shift_tz/3","title":"Tempus.Slot.shift_tz/3","type":"function"},{"doc":"Compares two slot structs. The same as compare/2 , but returns :joint if the slots are overlapped.","ref":"Tempus.Slot.html#strict_compare/2","title":"Tempus.Slot.strict_compare/2","type":"function"},{"doc":"Checks whether the Slot is valid (to &gt; from) or not. Examples iex&gt; slot = % Tempus.Slot { from : ~U|2015-09-30 00:00:00Z| , to : ~U|2015-10-01 01:00:00Z| } iex&gt; Tempus.Slot . valid? ( slot ) true iex&gt; Tempus.Slot . valid? ( % Tempus.Slot { from : slot . to , to : slot . from } ) false","ref":"Tempus.Slot.html#valid?/1","title":"Tempus.Slot.valid?/1","type":"function"},{"doc":"Wraps the argument into a slot. For DateTime it’d be a single microsecond. For a Date , it would be the whole day, starting at 00:00:00.000000 and ending at ` 23 : 59 : 59 : 999999 ` . Examples iex&gt; Tempus.Slot . wrap ( ~D|2020-08-06| ) # Slot &lt; [ from : ~U[2020-08-06 00:00:00.000000Z] , to : ~U[2020-08-06 23:59:59.999999Z] ] &gt;","ref":"Tempus.Slot.html#wrap/2","title":"Tempus.Slot.wrap/2","type":"function"},{"doc":"The origin used in comparisons and calculations","ref":"Tempus.Slot.html#t:origin/0","title":"Tempus.Slot.origin/0","type":"type"},{"doc":"A timeslot to be used in Tempus","ref":"Tempus.Slot.html#t:t/0","title":"Tempus.Slot.t/0","type":"type"},{"doc":"The ordered collection of slots, backed up by AVLTree . This module implements Enumerable and Collectable interfaces. Examples iex&gt; slots = [ ...&gt; Tempus.Slot . wrap ( ~D|2020-08-07| ) , ...&gt; Tempus.Slot . wrap ( ~D|2020-08-10| ) , ...&gt; % Tempus.Slot { ...&gt; from : ~U|2020-08-07 01:00:00Z| , to : ~U|2020-08-08 01:00:00Z| } ] ...&gt; Enum . into ( slots , % Tempus.Slots { } ) # Slots &lt; [ # Slot &lt; [ from : ~U[2020-08-07 00:00:00.000000Z] , to : ~U[2020-08-08 01:00:00Z] ] &gt; , # Slot &lt; [ from : ~U[2020-08-10 00:00:00.000000Z] , to : ~U[2020-08-10 23:59:59.999999Z] ] &gt; ] &gt; iex&gt; Enum . map ( slots , &amp; &amp;1 . from ) [ ~U[2020-08-07 00:00:00.000000Z] , ~U[2020-08-10 00:00:00.000000Z] , ~U[2020-08-07 01:00:00Z] ]","ref":"Tempus.Slots.html","title":"Tempus.Slots","type":"module"},{"doc":"Adds another slot to the slots collection. Joins slots intersecting with the new one, if any. Example iex&gt; Tempus.Slots . add ( % Tempus.Slots { } , Tempus.Slot . wrap ( ~D|2020-08-07| ) ) # Slots &lt; [ # Slot &lt; [ from : ~U[2020-08-07 00:00:00.000000Z] , to : ~U[2020-08-07 23:59:59.999999Z] ] &gt; ] &gt; iex&gt; % Tempus.Slots { } ...&gt; |&gt; Tempus.Slots . add ( Tempus.Slot . wrap ( ~D|2020-08-07| ) ) ...&gt; |&gt; Tempus.Slots . add ( Tempus.Slot . wrap ( ~D|2020-08-10| ) ) ...&gt; |&gt; Tempus.Slots . add ( % Tempus.Slot { ...&gt; from : ~U|2020-08-07 01:00:00Z| , to : ~U|2020-08-08 01:00:00Z| } ) # Slots &lt; [ # Slot &lt; [ from : ~U[2020-08-07 00:00:00.000000Z] , to : ~U[2020-08-08 01:00:00Z] ] &gt; , # Slot &lt; [ from : ~U[2020-08-10 00:00:00.000000Z] , to : ~U[2020-08-10 23:59:59.999999Z] ] &gt; ] &gt;","ref":"Tempus.Slots.html#add/3","title":"Tempus.Slots.add/3","type":"function"},{"doc":"Returns the AVL Tree instance of slots","ref":"Tempus.Slots.html#avl_tree/1","title":"Tempus.Slots.avl_tree/1","type":"function"},{"doc":"Inverses Slots returning the new Slots instance with slots set where there were blanks. Example iex&gt; [ ...&gt; Tempus.Slot . wrap ( ~D|2020-08-07| ) , ...&gt; Tempus.Slot . wrap ( ~D|2020-08-08| ) , ...&gt; Tempus.Slot . wrap ( ~D|2020-08-10| ) , ...&gt; Tempus.Slot . wrap ( ~D|2020-08-12| ) ...&gt; ] |&gt; Enum . into ( % Tempus.Slots { } ) ...&gt; |&gt; Tempus.Slots . inverse ( ) % Tempus.Slots { slots : [ % Tempus.Slot { from : nil , to : ~U[2020-08-06 23:59:59.999999Z] } , % Tempus.Slot { from : ~U[2020-08-09 00:00:00.000000Z] , to : ~U[2020-08-09 23:59:59.999999Z] } , % Tempus.Slot { from : ~U[2020-08-11 00:00:00.000000Z] , to : ~U[2020-08-11 23:59:59.999999Z] } , % Tempus.Slot { from : ~U[2020-08-13 00:00:00.000000Z] , to : nil } ] } iex&gt; [ ...&gt; % Tempus.Slot { to : ~U[2020-08-08 23:59:59.999999Z] } , ...&gt; Tempus.Slot . wrap ( ~D|2020-08-10| ) , ...&gt; % Tempus.Slot { from : ~U[2020-08-12 00:00:00.000000Z] } ...&gt; ] |&gt; Enum . into ( % Tempus.Slots { } ) ...&gt; |&gt; Tempus.Slots . inverse ( ) % Tempus.Slots { slots : [ % Tempus.Slot { from : ~U[2020-08-09 00:00:00.000000Z] , to : ~U[2020-08-09 23:59:59.999999Z] } , % Tempus.Slot { from : ~U[2020-08-11 00:00:00.000000Z] , to : ~U[2020-08-11 23:59:59.999999Z] } ] }","ref":"Tempus.Slots.html#inverse/2","title":"Tempus.Slots.inverse/2","type":"function"},{"doc":"Merges many slots into the first element in the list given as an argument. Other arguments might be streams, the first one must be a Tempus.Slots instance. Examples iex&gt; slots = [ ...&gt; Tempus.Slot . wrap ( ~D|2020-08-07| ) , ...&gt; Tempus.Slot . wrap ( ~D|2020-08-10| ) ...&gt; ] |&gt; Enum . into ( % Tempus.Slots { } ) iex&gt; other = [ ...&gt; % Tempus.Slot { from : ~U|2020-08-07 23:00:00Z| , to : ~U|2020-08-08 12:00:00Z| } , ...&gt; % Tempus.Slot { from : ~U|2020-08-12 23:00:00Z| , to : ~U|2020-08-12 23:30:00Z| } ...&gt; ] iex&gt; Tempus.Slots . merge ( [ slots , other ] ) # Slots &lt; [ # Slot &lt; [ from : ~U[2020-08-07 00:00:00.000000Z] , to : ~U[2020-08-08 12:00:00Z] ] &gt; , # Slot &lt; [ from : ~U[2020-08-10 00:00:00.000000Z] , to : ~U[2020-08-10 23:59:59.999999Z] ] &gt; , # Slot &lt; [ from : ~U[2020-08-12 23:00:00Z] , to : ~U[2020-08-12 23:30:00Z] ] &gt; ] &gt; iex&gt; Tempus.Slots . merge ( [ slots , Stream . map ( other , &amp; &amp;1 ) ] ) # Slots &lt; [ # Slot &lt; [ from : ~U[2020-08-07 00:00:00.000000Z] , to : ~U[2020-08-08 12:00:00Z] ] &gt; , # Slot &lt; [ from : ~U[2020-08-10 00:00:00.000000Z] , to : ~U[2020-08-10 23:59:59.999999Z] ] &gt; , # Slot &lt; [ from : ~U[2020-08-12 23:00:00Z] , to : ~U[2020-08-12 23:30:00Z] ] &gt; ] &gt;","ref":"Tempus.Slots.html#merge/1","title":"Tempus.Slots.merge/1","type":"function"},{"doc":"Merges other into this slots instance. other might be Enum or Stream . When other is a stream, it gets terminated immediately after the last element in this . Examples iex&gt; slots = [ ...&gt; Tempus.Slot . wrap ( ~D|2020-08-07| ) , ...&gt; Tempus.Slot . wrap ( ~D|2020-08-10| ) ...&gt; ] |&gt; Enum . into ( % Tempus.Slots { } ) iex&gt; other = [ ...&gt; % Tempus.Slot { from : ~U|2020-08-07 23:00:00Z| , to : ~U|2020-08-08 12:00:00Z| } , ...&gt; % Tempus.Slot { from : ~U|2020-08-12 23:00:00Z| , to : ~U|2020-08-12 23:30:00Z| } ...&gt; ] iex&gt; Tempus.Slots . merge ( slots , other ) # Slots &lt; [ # Slot &lt; [ from : ~U[2020-08-07 00:00:00.000000Z] , to : ~U[2020-08-08 12:00:00Z] ] &gt; , # Slot &lt; [ from : ~U[2020-08-10 00:00:00.000000Z] , to : ~U[2020-08-10 23:59:59.999999Z] ] &gt; , # Slot &lt; [ from : ~U[2020-08-12 23:00:00Z] , to : ~U[2020-08-12 23:30:00Z] ] &gt; ] &gt; iex&gt; Tempus.Slots . merge ( slots , Stream . map ( other , &amp; &amp;1 ) ) # Slots &lt; [ # Slot &lt; [ from : ~U[2020-08-07 00:00:00.000000Z] , to : ~U[2020-08-08 12:00:00Z] ] &gt; , # Slot &lt; [ from : ~U[2020-08-10 00:00:00.000000Z] , to : ~U[2020-08-10 23:59:59.999999Z] ] &gt; , # Slot &lt; [ from : ~U[2020-08-12 23:00:00Z] , to : ~U[2020-08-12 23:30:00Z] ] &gt; ] &gt;","ref":"Tempus.Slots.html#merge/2","title":"Tempus.Slots.merge/2","type":"function"},{"doc":"Returns the number of slots","ref":"Tempus.Slots.html#size/1","title":"Tempus.Slots.size/1","type":"function"},{"doc":"Wraps the argument into a slots instance. For nil it’d be an empty slots. For everything else it’d call Slot.wrap/1 on an argument and add it to empty slots. Examples iex&gt; Tempus.Slots . wrap ( ~D|2020-08-06| ) # Slots &lt; [ # Slot &lt; [ from : ~U[2020-08-06 00:00:00.000000Z] , to : ~U[2020-08-06 23:59:59.999999Z] ] &gt; ] &gt;","ref":"Tempus.Slots.html#wrap/1","title":"Tempus.Slots.wrap/1","type":"function"},{"doc":"AVL Tree specialized for Tempus slots type","ref":"Tempus.Slots.html#t:avl_tree/0","title":"Tempus.Slots.avl_tree/0","type":"type"},{"doc":"","ref":"Tempus.Slots.html#t:t/0","title":"Tempus.Slots.t/0","type":"type"},{"doc":"Raised at runtime when an argument passed to function is invalid","ref":"Tempus.ArgumentError.html","title":"Tempus.ArgumentError","type":"exception"},{"doc":"Easy handling of time periods aka slots, like business days, holidays, etc.","ref":"readme.html","title":"Tempus","type":"extras"},{"doc":"def deps do [ { :tempus , &quot;~&gt; 0.1&quot; } ] end","ref":"readme.html#installation","title":"Tempus - Installation","type":"extras"},{"doc":"0.9.1 — Tempus.Sigils.parse/1 0.9.0 — Tempus.Guards , Tempus.slot/{1,2} , Tempus.guess/1 , better sigils, prepared for :tempus_sql 0.8.0 — improve Tempus.Sigils , prepared for :tempus_sql 0.7.3 — truncate: boolean() | non_neg_integer() to truncate Slots inspection 0.7.2 — Slots.merge/1 0.7.1 — treat infinite slot as special not-covering anything 0.7.0  —  merge/2 is 6× faster, Slot.neighbour?/2 , Tempus.slice/4 , Tempus.drop_while/2 , Tempus.take_while/2 0.6.0  — compatibility with Elixir v1.14 (no greek in variables names) meh 0.5.0  — stricter :telemetria support 0.4.2  — make :telemetria dependency fully optional 0.4.0  —  ~I sigil to ease slots creation, wrap date/times, fancy inspect 0.3.0  — drastical performance improvements, benchmarks 0.2.4  — fixed bug when finding next free/busy for empty slots 0.2.3  — correctly handle empty slots in next_busy/2 / next_free/2 0.2.2  —  Slot.shift_tz/3 0.2.1  — accept function as well as stream in Slots.merge/2 0.2.0  — many improvements, Tempus.add/2 similar to DateTime.add/4 but considering slots","ref":"readme.html#changelog","title":"Tempus - Changelog","type":"extras"},{"doc":"","ref":"readme.html#documentation","title":"Tempus - Documentation","type":"extras"},{"doc":"","ref":"getting-started.html","title":"Getting Started","type":"extras"},{"doc":"Tempus library provides an easy way to handle and manipulate time slots. TYime slot is the base concept behind the library. It is basically the struct, containing from and to instances of DateTime . One might provide the list of slots, as Enum or as a Stream , and check whether another time slot and/or DateTime instance is overlapped or disjoined. Also one might get the next “available” slot(s) providing an origin , as well as next busy slot(s). It might be used e. g. to calculate the working days between now and some day in the future, providing the list of holidays, and the stream of weekends.","ref":"getting-started.html#usecases","title":"Getting Started - Usecases","type":"extras"},{"doc":"Tempus.Slots module leverages AVLTree . It exposes add/2 , merge/2 and inverse/2 functions to add slots, merge the slots with another slot(s) and/or Stream , and inverse the slots respecively. Typically one starts with something like slots = [ Tempus.Slot . wrap ( ~D|2020-08-07| ) , Tempus.Slot . wrap ( ~D|2020-08-10| ) , % Tempus.Slot { from : ~U|2020-08-07 01:00:00Z| , to : ~U|2020-08-08 01:00:00Z| } ] |&gt; Enum . into ( % Tempus.Slots { } ) When updated, Tempus.Slots joins the newly added slot(s) into the set of existing ones, so thet at any moment there is no overlapped slots. This happens when new slot is added with Tempus.Slots.add/2 and when the enumerable is collected. Consuming Streams Tempus.Slots is optimized for reads, that’s why internally it keeps slots as an Enum . It only allows to merge Stream into the existing Tempus.Slots and the stream will be terminated within the range of the Enum already presented. Below is the example of consuming the stream. holidays = [ ~D|2020-08-06| , ~D|2020-08-13| ] weekends = Stream . map ( [ ~D|2020-08-08| , ~D|2020-08-20| ] , &amp; &amp;1 ) schedule = holidays |&gt; Enum . into ( % Slots { } ) |&gt; Slots . merge ( weekends ) #⇒ #Slots&lt;[ # #Slot&lt;[ # from: ~U[2020-08-06 00:00:00.000000Z], # to: ~U[2020-08-06 23:59:59.999999Z] # ]&gt;, # #Slot&lt;[ # from: ~U[2020-08-08 00:00:00.000000Z], # to: ~U[2020-08-08 23:59:59.999999Z] # ]&gt;, # #Slot&lt;[ # from: ~U[2020-08-13 00:00:00.000000Z], # to: ~U[2020-08-13 23:59:59.999999Z] # ]&gt; # ]&gt;","ref":"getting-started.html#initializing-slots","title":"Getting Started - Initializing Slots","type":"extras"},{"doc":"With a help of Tempus.next_busy/2 and Tempus.next_free/2 , one might get the next busy and/or free slot(s). To calculate the first free slot in 5 business days after 2020-08-05 , the following is to be done. holidays = [ ~D|2020-08-07| , ~D|2020-08-13| ] # ... weekends = [ ~D|2020-08-08| , ~D|2020-08-09| ] # ... holidays |&gt; Enum . into ( % Slots { } ) |&gt; Tempus.Slots . merge ( weekends ) |&gt; Tempus . days_ahead ( ~D|2020-08-05| , 5 ) |&gt; hd ( ) #⇒ &quot;2020-08-14&quot;","ref":"getting-started.html#checking-state","title":"Getting Started - Checking State","type":"extras"}]